#
# spec file for package libXfont2
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXfont2
%define lname   libXfont2-2
Version:        2.0.6
Release:        1.5
Summary:        X font handling library for server and utilities
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXfont
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXfont/
Source:         %{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontenc)
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(xorg-macros) >= 1.10
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xtrans)
BuildRequires:  pkgconfig(zlib)
#optional#BuildRequires:	pkgconfig(bzip2), + --with-bzip2

%description
libXfont provides the core of the legacy X11 font system, handling
the index files (fonts.dir, fonts.alias, fonts.scale), the various
font file formats, and rasterizing them. It is used by the X servers,
the X Font Server (xfs), and some font utilities (bdftopcf for
instance), but should not be used by normal X11 clients. X11 clients
access fonts via either the new APIs in libXft, or the legacy APIs in
libX11.

%package -n %lname
Summary:        X font handling library for server and utilities
Group:          System/Libraries

%description -n %lname
libXfont provides the core of the legacy X11 font system, handling
the index files (fonts.dir, fonts.alias, fonts.scale), the various
font file formats, and rasterizing them. It is used by the X servers,
the X Font Server (xfs), and some font utilities (bdftopcf for
instance), but should not be used by normal X11 clients. X11 clients
access fonts via either the new APIs in libXft, or the legacy APIs in
libX11.

%package devel
Summary:        Development files for the X font handling library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libXfont provides the core of the legacy X11 font system, handling
the index files (fonts.dir, fonts.alias, fonts.scale), the various
font file formats, and rasterizing them. It is used by the X servers,
the X Font Server (xfs), and some font utilities (bdftopcf for
instance), but should not be used by normal X11 clients. X11 clients
access fonts via either the new APIs in libXft, or the legacy APIs in
libX11.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%configure --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%license COPYING
%_libdir/libXfont2.so.2*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libXfont2.so
%_libdir/pkgconfig/xfont2.pc

%changelog
* Sat Aug 27 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.0.6
  * gitlab CI: add a basic build test
  * Fix spelling/wording issues
  * configure: Use pkg-config to handle zlib dependency if possible
  * Fix comments to reflect removal of OS/2 support
* Mon Aug  2 2021 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.0.5
  * README: Remove mention of libXfont 1.5
  * Fix out-of-bounds read in FontFileMakeDir()
  * configure: define HAVE_LIBBSD when libbsd was found
  * Fix Win32 build since c4ed2e06 "Add some unit testing utilities"
  * Fix crash when font server connection lost
  * Fix use after free when font server connection lost
* Mon Sep 16 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.0.4
  * This minor maintenance release cleans up issues found by
    Coverity and gcc, as well as additional hardening through
    the use of APIs with stronger bounds checking.
- tag COPYING as license
* Tue Nov 28 2017 sndirsch@suse.com
- Update to version 2.0.3
  * Open files with O_NOFOLLOW. (CVE-2017-16611, bsc#1050459)
* Wed Oct 11 2017 tobias.johannes.klausmann@mni.thm.de
- Update to version 2.0.2:
  A collection of minor fixes since 2.0.1, including fixes for CVE 2017-13720
  and CVE 2017-13722.
* Fri Sep 23 2016 zaitor@opensuse.org
- Include COPYING in binary.
* Thu Sep 22 2016 jengelh@inai.de
- RPM group correction
* Tue Dec 22 2015 tobias.johannes.klausmann@mni.thm.de
- Initial package version 2.0.1:
  Here's the first version of a new libXfont2 library; it's the same as
  the old libXfont libary, but has a shiny new API/ABI that avoids
  referencing symbols in the X server directly. The code for the X server
  to use this version is awaiting review and merging still.
